DeviceColorsPatterns extension

Adds pattern-matching-related methods to DeviceColors.

on

Methods

map<TResult extends Object?>(TResult $default(_DeviceColors value)) → TResult

Available on DeviceColors, provided by the DeviceColorsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_DeviceColors value)?) → TResult?

Available on DeviceColors, provided by the DeviceColorsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_DeviceColors value)?, {required TResult orElse()}) → TResult

Available on DeviceColors, provided by the DeviceColorsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? buttonMouseOverBackgroundColor, String? buttonPressedBackgroundColor, String? buttonPressedBorderColor, String? buttonPressedTextColor, String? highlightColor)?, {required TResult orElse()}) → TResult

Available on DeviceColors, provided by the DeviceColorsPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String? buttonMouseOverBackgroundColor, String? buttonPressedBackgroundColor, String? buttonPressedBorderColor, String? buttonPressedTextColor, String? highlightColor)) → TResult

Available on DeviceColors, provided by the DeviceColorsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? buttonMouseOverBackgroundColor, String? buttonPressedBackgroundColor, String? buttonPressedBorderColor, String? buttonPressedTextColor, String? highlightColor)?) → TResult?

Available on DeviceColors, provided by the DeviceColorsPatterns extension

A variant of when that fallback to returning null