DialUpEvent class sealed

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

DialUpEvent({required String action, required String context, required String device, required DialPressPayload payload})
const
factory
DialUpEvent.fromJson(Map<String, dynamic> json)
factory

Properties

action String
no setterinherited
context String
no setterinherited
copyWith → $DialUpEventCopyWith<DialUpEvent>
Create a copy of DialUpEvent with the given fields replaced by the non-null parameter values.
no setterinherited
device String
no setterinherited
event String
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
payload DialPressPayload
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_DialUpEvent value)) → TResult

Available on DialUpEvent, provided by the DialUpEventPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_DialUpEvent value)?) → TResult?

Available on DialUpEvent, provided by the DialUpEventPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_DialUpEvent value)?, {required TResult orElse()}) → TResult

Available on DialUpEvent, provided by the DialUpEventPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String action, String context, String device, DialPressPayload payload)?, {required TResult orElse()}) → TResult

Available on DialUpEvent, provided by the DialUpEventPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String action, String context, String device, DialPressPayload payload)) → TResult

Available on DialUpEvent, provided by the DialUpEventPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String action, String context, String device, DialPressPayload payload)?) → TResult?

Available on DialUpEvent, provided by the DialUpEventPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited