DidReceiveGlobalSettingsEvent class sealed

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

DidReceiveGlobalSettingsEvent({required Map<String, Object?> payload})
const
factory
DidReceiveGlobalSettingsEvent.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $DidReceiveGlobalSettingsEventCopyWith<DidReceiveGlobalSettingsEvent>
Create a copy of DidReceiveGlobalSettingsEvent with the given fields replaced by the non-null parameter values.
no setterinherited
event String
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
payload Map<String, Object?>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings Map<String, Object?>
no setter

Methods

map<TResult extends Object?>(TResult $default(_DidReceiveGlobalSettingsEvent value)) → TResult

Available on DidReceiveGlobalSettingsEvent, provided by the DidReceiveGlobalSettingsEventPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_DidReceiveGlobalSettingsEvent value)?) → TResult?

Available on DidReceiveGlobalSettingsEvent, provided by the DidReceiveGlobalSettingsEventPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_DidReceiveGlobalSettingsEvent value)?, {required TResult orElse()}) → TResult

Available on DidReceiveGlobalSettingsEvent, provided by the DidReceiveGlobalSettingsEventPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(Map<String, Object?> payload)?, {required TResult orElse()}) → TResult

Available on DidReceiveGlobalSettingsEvent, provided by the DidReceiveGlobalSettingsEventPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(Map<String, Object?> payload)) → TResult

Available on DidReceiveGlobalSettingsEvent, provided by the DidReceiveGlobalSettingsEventPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(Map<String, Object?> payload)?) → TResult?

Available on DidReceiveGlobalSettingsEvent, provided by the DidReceiveGlobalSettingsEventPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited