ManifestTriggerDescription class sealed

Available extensions
Annotations
  • @freezed

Constructors

ManifestTriggerDescription({@JsonKey.new(name: 'Rotate') String? rotate, @JsonKey.new(name: 'Push') String? push, @JsonKey.new(name: 'Touch') String? touch, @JsonKey.new(name: 'LongTouch') String? longTouch})
const
factory
ManifestTriggerDescription.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $ManifestTriggerDescriptionCopyWith<ManifestTriggerDescription>
Create a copy of ManifestTriggerDescription with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
longTouch String?
no setterinherited
push String?
no setterinherited
rotate String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
touch String?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ManifestTriggerDescription value)) → TResult

Available on ManifestTriggerDescription, provided by the ManifestTriggerDescriptionPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ManifestTriggerDescription value)?) → TResult?

Available on ManifestTriggerDescription, provided by the ManifestTriggerDescriptionPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ManifestTriggerDescription value)?, {required TResult orElse()}) → TResult

Available on ManifestTriggerDescription, provided by the ManifestTriggerDescriptionPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? rotate, String? push, String? touch, String? longTouch)?, {required TResult orElse()}) → TResult

Available on ManifestTriggerDescription, provided by the ManifestTriggerDescriptionPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ManifestTriggerDescription to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? rotate, String? push, String? touch, String? longTouch)) → TResult

Available on ManifestTriggerDescription, provided by the ManifestTriggerDescriptionPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? rotate, String? push, String? touch, String? longTouch)?) → TResult?

Available on ManifestTriggerDescription, provided by the ManifestTriggerDescriptionPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited