PropertyInspectorDidAppearEvent class sealed

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

PropertyInspectorDidAppearEvent({required String action, required String context, required String device})
const
factory
PropertyInspectorDidAppearEvent.fromJson(Map<String, dynamic> json)
factory

Properties

action String
no setterinherited
context String
no setterinherited
copyWith → $PropertyInspectorDidAppearEventCopyWith<PropertyInspectorDidAppearEvent>
Create a copy of PropertyInspectorDidAppearEvent with the given fields replaced by the non-null parameter values.
no setterinherited
device String
no setterinherited
event String
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_PropertyInspectorDidAppearEvent value)) → TResult

Available on PropertyInspectorDidAppearEvent, provided by the PropertyInspectorDidAppearEventPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PropertyInspectorDidAppearEvent value)?) → TResult?

Available on PropertyInspectorDidAppearEvent, provided by the PropertyInspectorDidAppearEventPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PropertyInspectorDidAppearEvent value)?, {required TResult orElse()}) → TResult

Available on PropertyInspectorDidAppearEvent, provided by the PropertyInspectorDidAppearEventPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String action, String context, String device)?, {required TResult orElse()}) → TResult

Available on PropertyInspectorDidAppearEvent, provided by the PropertyInspectorDidAppearEventPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String action, String context, String device)) → TResult

Available on PropertyInspectorDidAppearEvent, provided by the PropertyInspectorDidAppearEventPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String action, String context, String device)?) → TResult?

Available on PropertyInspectorDidAppearEvent, provided by the PropertyInspectorDidAppearEventPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited